LangModel class

Constructors

LangModel({required String okConexion, required String errorConexion, required String generalError, required String redErrorConexion})

Properties

errorConexion ↔ String
getter/setter pair
generalError ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
okConexion ↔ String
getter/setter pair
redErrorConexion ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited